#ifndef NT2_INCLUDE_FUNCTIONS_ISDIAGONAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISDIAGONAL_HPP_INCLUDED

#include <nt2/predicates/include/functions/isdiagonal.hpp>

#endif
